@@ -53,6 +53,15 @@ impl AWSMachineTemplate {
         self
     }
 
+    #[must_use]
+    pub fn ami(mut self, id: &str) -> Self {
+        let id = id.to_string();
+        let mut ami = self.spec.template.spec.ami.unwrap_or_default();
+        ami.id = Some(id);
+        self.spec.template.spec.ami = Some(ami);
+        self
+    }
+
     #[must_use]
     pub fn root_volume(mut self, root_volume: Volume) -> Self {
         self.spec.template.spec.root_volume = Some(root_volume);
